@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2004-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2004-2021 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 // ----------------------------------------------------------------------------
 
 
+#include "global.h"
 #include "gobjects.h"
 
 
@@ -75,15 +76,20 @@ void GUI_bgroup::init (X_window *W, X_callback *C, X_button_style *B, int k, int
 
     _callb = C;
     _cbnum = k;
-    T = new X_textip (W, 0, &Tst1, x, y, 40, 17, 12);
-    T->set_text (label);
-    T->x_map ();    
+    if (label)
+    {
+        T = new X_textip (W, 0, &Tst1, x, y, 40, 17, 12);
+        T->set_text (label);
+        T->x_map ();
+	x += 45;
+    }
     B->size.x = 35;
     B->size.y = 17;
     for (i = 0; texts [i]; i++)
     {
-	_butt [i] = new X_tbutton (W, this, B, x + 45 + 36 * i, y, texts [i], 0, i);
+	_butt [i] = new X_tbutton (W, this, B, x, y, texts [i], 0, i);
         _butt [i]->x_map ();
+	x += 36;
     }
     _state = -1;
 }
@@ -141,22 +147,25 @@ void GUI_input::init (X_window *W, X_callback *C, int k, int x, int y)
 	_binp [i] = new X_tbutton (W, this, B, x + 18 * i, y, s, 0, INP1 + i);
         _binp [i]->x_map ();
     }    
-    if (k) _input = -1;
-    else
-    {
-	_binp [0]->set_stat (1);
-        _input = 0;
-    }
 
+    // if (k) _input = -1;
+    // else
+    // {
+    // 	_binp [0]->set_stat (1);
+    //     _input = 0;
+    // }
+
+    _binp [k]->set_stat (1);
+    _input = k;
+    
     Bst0.size.x = 15;
     Bst0.size.y = 15;
     y += 18;
     (new X_ibutton (W, this, &Bst0, x,      y + 1, W->disp ()->image1515 (X_display::IMG_LT), DEC))->x_map ();
     (new X_ibutton (W, this, &Bst0, x + 16, y + 1, W->disp ()->image1515 (X_display::IMG_RT), INC))->x_map ();
     _tgain = new X_textip (W, this, &Tst0, x + 35, y, 38, 16, 8);
-    _tgain->set_text ("10");
     _tgain->x_map ();
-    _gain = 10.0f;
+    set_gain (15.0f);
   
     y += 18;
     Bst0.size.x = 35;
@@ -166,6 +175,7 @@ void GUI_input::init (X_window *W, X_callback *C, int k, int x, int y)
     {
       _blink =new X_tbutton (W, this, &Bst0, x + 36, y, "Lnk", 0, LINK);
       _blink->x_map ();
+      _blink->set_stat (0);
     }
     else _blink = 0;
 }
@@ -279,23 +289,38 @@ void GUI_memory::init (X_window *W, X_callback *C, int k, int x, int y)
     B = k ? &BstB : &BstA;
     B->size.x = Bst0.size.x = 36;
     B->size.y = Bst0.size.y = 17;
-    (new X_tbutton (W, this, B    , x,      y + 18, "PkH", 0, CB_PEAK))->x_map ();
-    (new X_tbutton (W, this, &Bst0, x,      y + 36, "->X", 0, CB_MEMX))->x_map ();
-    (new X_tbutton (W, this, &Bst0, x + 36, y + 36, "->Y", 0, CB_MEMY))->x_map ();
-    _peak = false;
+    (new X_tbutton (W, this, B    , x,      y + 18, "Pk" , 0, CB_PEAK))->x_map ();
+    (new X_tbutton (W, this, B    , x + 36, y + 18, "Av",  0, CB_AVER))->x_map ();
+    (new X_tbutton (W, this, &Bst0, x,      y + 36, "Res", 0, CB_MRES))->x_map ();
+    (new X_tbutton (W, this, &Bst0, x,      y + 54, "->X", 0, CB_MEMX))->x_map ();
+    (new X_tbutton (W, this, &Bst0, x + 36, y + 54, "->Y", 0, CB_MEMY))->x_map ();
+    _mode = MM_NONE;
 }
 
 
 void GUI_memory::handle_callb (int k, X_window *W, _XEvent *E)
 {
     X_button  *B;
-    int       i;
+    int       i, s;
 
     if (k == (X_callback::BUTTON | X_button::PRESS))
     {
 	B = (X_button *) W;
         i = B->cbid ();
-        if (i == CB_PEAK) B->set_stat (_peak = ! B->stat ()); 
+        s = B->stat ();
+	switch (i)
+	{
+	case CB_PEAK:
+	    if (_mode == MM_AVER) return;
+	    if (s) { B->set_stat (0); _mode = MM_NONE; }
+	    else   { B->set_stat (1); _mode = MM_PEAK; }
+	    break;
+	case CB_AVER:
+	    if (_mode == MM_PEAK) return;
+	    if (s) { B->set_stat (0); _mode = MM_NONE; }
+	    else   { B->set_stat (1); _mode = MM_AVER; }
+	    break;
+	}
         _callb->handle_callb (_group | i, 0, 0);
     } 
 }
@@ -308,21 +333,24 @@ void GUI_traces::init (X_window *W, X_callback *C, int x, int y)
     T = new X_textip (W, 0, &Tst1, x + 30, y, 64, 17, 12);
     T->set_text ("Traces");
     T->x_map ();
-    _traceA.init (W, C, &BstA, CB_TRACEA, x, y + 18, "In A", _traceA_texts);
-    _traceB.init (W, C, &BstB, CB_TRACEB, x, y + 36, "In B", _traceB_texts);
-    _traceM.init (W, C, &BstM, CB_TRACEM, x, y + 54, "Mem",  _traceM_texts);
+    _traceA.init (W, C, &BstA, CB_TRACEA, x, y + 18, 0, _traceA_texts);
+    _traceB.init (W, C, &BstB, CB_TRACEB, x, y + 36, 0, _traceB_texts);
+    _traceX.init (W, C, &BstX, CB_TRACEM, x, y + 54, 0, _traceX_texts);
+    _traceY.init (W, C, &BstY, CB_TRACEM, x, y + 72, 0, _traceY_texts);
     _traceA.set_state (0);
+    _traceB.set_state (1);
 }
 
-const char *GUI_traces::_traceA_texts [] = { "A" , "A/B", "A/X", 0 };
-const char *GUI_traces::_traceB_texts [] = { "B" , "B/X", "B/Y", 0 };
-const char *GUI_traces::_traceM_texts [] = { "X" , "Y",   "X/Y", 0 };
+const char *GUI_traces::_traceA_texts [] = { "A",   "A/B", "A/X", "A/Y", 0 };
+const char *GUI_traces::_traceB_texts [] = { "B/A", "B",   "B/X", "B/Y", 0 };
+const char *GUI_traces::_traceX_texts [] = { "X/A", "X/B", "X",   "X/Y", 0 };
+const char *GUI_traces::_traceY_texts [] = { "Y/A", "Y/B", "Y/X", "Y",   0 };
 
 
 void GUI_display::init (X_window *W, X_callback *C, int x, int y)
 {
     _ascale.init (W, C, CB_ASCALE, x,       y, "Range", _ascale_texts);
-    _ascale.set_state (1);
+    _ascale.set_state (3);
     _fscale.init (W, C, CB_FSCALE, x + 150, y, "Scale", _fscale_texts);
     _fscale.set_state (1);
     _arespf.init (W, C, CB_ARESPF, x + 300, y, "Resp",  _arespf_texts);
