@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2004-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2004-2021 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,27 +25,6 @@
 #include "styles.h"
 
 
-enum 
-{
-    CB_INPUT,
-    CB_GAIN,
-    CB_AUTO,
-    CB_LINK,
-    CB_PEAK,
-    CB_MEMX,
-    CB_MEMY,
-    CB_RESOL,
-    CB_WFACT,
-    CB_SPEED,
-    CB_TRACEA,
-    CB_TRACEB,
-    CB_TRACEM,
-    CB_ASCALE,
-    CB_FSCALE,
-    CB_ARESPF
-};
- 
-
 class GUI_select : public X_callback
 {
 public:
@@ -85,7 +64,7 @@ private:
     virtual void handle_callb (int k, X_window *W, _XEvent *E);
 
     X_callback  *_callb;
-    X_button    *_butt [3];
+    X_button    *_butt [4];
     int          _cbnum;
     int          _state;
 };
@@ -145,7 +124,7 @@ class GUI_memory : public X_callback
 public:
 
     void init (X_window *W, X_callback *C, int k, int x, int y);    
-    bool get_peak (void) const { return _peak; }
+    int get_mode (void) const { return _mode; }
 
     virtual ~GUI_memory (void) {}
 
@@ -155,7 +134,7 @@ private:
     
     X_callback *_callb;
     int         _group;
-    bool        _peak; 
+    int         _mode; 
 };
 
 
@@ -166,17 +145,20 @@ public:
     void init (X_window *W, X_callback *C, int x, int y);    
     int get_traceA (void) const { return _traceA.get_state (); } 
     int get_traceB (void) const { return _traceB.get_state (); } 
-    int get_traceM (void) const { return _traceM.get_state (); } 
+    int get_traceX (void) const { return _traceX.get_state (); } 
+    int get_traceY (void) const { return _traceY.get_state (); } 
 
 private:
 
     GUI_bgroup  _traceA;
     GUI_bgroup  _traceB;
-    GUI_bgroup  _traceM;
+    GUI_bgroup  _traceX;
+    GUI_bgroup  _traceY;
 
     static const char *_traceA_texts [];
     static const char *_traceB_texts [];
-    static const char *_traceM_texts [];
+    static const char *_traceX_texts [];
+    static const char *_traceY_texts [];
 };
 
 
