@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2004-2018 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2004-2021 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <math.h>
 #include "styles.h"
+#include "global.h"
 #include "mainwin.h"
 #include "messages.h"
 
@@ -82,7 +83,7 @@ Mainwin::Mainwin (X_window *parent, X_resman *xres, ITC_ctrl *audio) :
     _gui_analys.init (_bwin1, this, 4, 84);
     _gui_memory [0].init (_bwin1, this, 0,  4, 164);
     _gui_memory [1].init (_bwin1, this, 1, 84, 164);
-    _gui_traces.init (_bwin1, this, 4, 226);
+    _gui_traces.init (_bwin1, this, 4, 244);
     _gui_display.init (_bwin2, this, 0, 2);
 
     x_add_events (ExposureMask | StructureNotifyMask);
@@ -218,14 +219,13 @@ void Mainwin::handle_callb (int k, X_window *W, _XEvent *E )
         set_speed ();
 	break;
 
-    case CB_PEAK:
-        assert (c >= 0);
-        if (! _gui_memory [c].get_peak ()) _chan [c]->clr_peak ();       
+    case CB_MRES:
+        _chan [c]->clr_peak ();       
 	break;
 
     case CB_MEMX:
     case CB_MEMY:
-        ts = (_gui_memory [c].get_peak ()) ? _chan [c]->peakp () : _chan [c]->power ();
+        ts = (_gui_memory [c].get_mode ()) ? _chan [c]->peakp () : _chan [c]->power ();
         td = (k == CB_MEMX) ? _memX : _memY;
         set_memory (td, ts, _gain [c]);        
 	break;
@@ -284,7 +284,7 @@ void Mainwin::show_about (void)
     D.drawstring (PROGNAME, 0); 
     D.setfont (XftFonts.about2);
     D.move (x, y);
-    D.drawstring ("(C) 2004-2013 Fons Adriaensen", 0); 
+    D.drawstring ("(C) 2004-2021 Fons Adriaensen", 0); 
     D.move (x, y + 50);
     D.drawstring ("This is free software, and you are welcome to distribute it", 0); 
     D.move (x, y + 70);
@@ -519,17 +519,30 @@ void Mainwin::plot_data (void)
             if (pkA->_valid) plot_trace (Colors.spect_pkA, pkA->_data, _memX->_data, _gain [0]); 
             if (trA->_valid) plot_trace (Colors.spect_trA, trA->_data, _memX->_data, _gain [0]); 
 	}
-       break;
+	break;
+
+    case 3:
+	if (_memY->_valid)
+	{
+            if (pkA->_valid) plot_trace (Colors.spect_pkA, pkA->_data, _memY->_data, _gain [0]); 
+            if (trA->_valid) plot_trace (Colors.spect_trA, trA->_data, _memY->_data, _gain [0]); 
+	}
+	break;
     }
 
     switch (_gui_traces.get_traceB ())
     {
     case 0:
-       if (pkB->_valid) plot_trace (Colors.spect_pkB, pkB->_data, 0, _gain [1]);
-       if (trB->_valid) plot_trace (Colors.spect_trB, trB->_data, 0, _gain [1]);
-       break;
+        if (pkB->_valid && pkA->_valid) plot_trace (Colors.spect_pkB, pkB->_data, pkA->_data, _gain [1] / _gain [0]); 
+        if (trB->_valid && trA->_valid) plot_trace (Colors.spect_trB, trB->_data, trA->_data, _gain [1] / _gain [0]); 
+        break;
 
     case 1:
+	if (pkB->_valid) plot_trace (Colors.spect_pkB, pkB->_data, 0, _gain [1]);
+	if (trB->_valid) plot_trace (Colors.spect_trB, trB->_data, 0, _gain [1]);
+	break;
+
+    case 2:
 	if (_memX->_valid)
 	{
             if (pkB->_valid) plot_trace (Colors.spect_pkB, pkB->_data, _memX->_data, _gain [1]); 
@@ -537,7 +550,7 @@ void Mainwin::plot_data (void)
 	}
         break;
 
-    case 2:
+    case 3:
 	if (_memY->_valid)
 	{
             if (pkB->_valid) plot_trace (Colors.spect_pkB, pkB->_data, _memY->_data, _gain [1]); 
@@ -546,19 +559,48 @@ void Mainwin::plot_data (void)
         break;
     }
 
-    switch (_gui_traces.get_traceM ())
+    if (_memX->_valid)
     {
-    case 0:
-        if (_memX->_valid) plot_trace (Colors.spect_trM, _memX->_data, 0, 1.0f);
-        break;
+	switch (_gui_traces.get_traceX ())
+	{
+	case 0:
+	    if (trA->_valid) plot_trace (Colors.spect_trX, _memX->_data, trA->_data, 1.0f / _gain [0]);
+	    break;
 
-    case 1:
-        if (_memY->_valid) plot_trace (Colors.spect_trM, _memY->_data, 0, 1.0f);
-        break;
+	case 1:
+	    if (trB->_valid) plot_trace (Colors.spect_trX, _memX->_data, trB->_data, 1.0f / _gain [1]); 
+	    break;
 
-    case 2:
-        if (_memX->_valid && _memY->_valid) plot_trace (Colors.spect_trM, _memX->_data, _memY->_data, 1.0f); 
-	break;
+	case 2:
+	    plot_trace (Colors.spect_trX, _memX->_data, 0, 1.0f);
+	    break;
+
+	case 3:
+	    if (_memY->_valid) plot_trace (Colors.spect_trX, _memX->_data, _memY->_data, 1.0f); 
+	    break;
+	}
+    }
+
+    if (_memY->_valid)
+    {
+    	switch (_gui_traces.get_traceY ())
+	{
+	case 0:
+	    if (trA->_valid) plot_trace (Colors.spect_trY, _memY->_data, trA->_data, 1.0f / _gain [0]);
+	    break;
+
+	case 1:
+	    if (trB->_valid) plot_trace (Colors.spect_trY, _memY->_data, trB->_data, 1.0f / _gain [1]); 
+	    break;
+
+	case 2:
+	    if (_memY->_valid) plot_trace (Colors.spect_trY, _memY->_data, _memX->_data, 1.0f); 
+	    break;
+
+	case 3:
+	    plot_trace (Colors.spect_trY, _memY->_data, 0, 1.0f);
+	    break;
+	}
     }
 }
 
@@ -673,9 +715,9 @@ void Mainwin::handle_trig ()
         return;
     }        
     if (_gui_input [0].get_input () < 0) _chan [0]->ipskip (_ipstep);
-    else _chan [0]->process (_ipstep, _gui_memory [0].get_peak ());
+    else _chan [0]->process (_ipstep, _gui_memory [0].get_mode ());
     if (_gui_input [1].get_input () < 0) _chan [1]->ipskip (_ipstep);
-    else _chan [1]->process (_ipstep, _gui_memory [1].get_peak ());
+    else _chan [1]->process (_ipstep, _gui_memory [1].get_mode ());
     update ();
 }
 
