@@ -26,7 +26,7 @@ struct fonts       Fonts;
 struct xft_colors  XftColors;
 struct xft_fonts   XftFonts;
 
-X_button_style  Bst0, BstA, BstB, BstM;
+X_button_style  Bst0, BstA, BstB, BstX, BstY;
 X_textln_style  Tst0, Tst1;
 
 
@@ -39,16 +39,18 @@ void init_styles (X_display *disp, X_resman *xrm)
     Colors.main_ls   = disp->alloc_color (xrm->get (".color.main.ls",   "white"),     Colors.white);
     Colors.spect_bg  = disp->alloc_color (xrm->get (".color.spect.bg",  "white"),     Colors.white);
     Colors.spect_gr  = disp->alloc_color (xrm->get (".color.spect.gr",  "gray80"),    Colors.white);
-    Colors.spect_trA = disp->alloc_color (xrm->get (".color.spect.trA", "red"),       Colors.black);
-    Colors.spect_pkA = disp->alloc_color (xrm->get (".color.spect.pkA", "#FFA0A0"),   Colors.black);
-    Colors.spect_trB = disp->alloc_color (xrm->get (".color.spect.trB", "blue"),      Colors.black);
-    Colors.spect_pkB = disp->alloc_color (xrm->get (".color.spect.pkB", "#A0A0FF"),   Colors.black);
-    Colors.spect_trM = disp->alloc_color (xrm->get (".color.spect.trM", "darkgreen"), Colors.white);
+    Colors.spect_trA = disp->alloc_color (xrm->get (".color.spect.trA", "#FF0000"),   Colors.black);
+    Colors.spect_pkA = disp->alloc_color (xrm->get (".color.spect.pkA", "#FF8080"),   Colors.black);
+    Colors.spect_trB = disp->alloc_color (xrm->get (".color.spect.trB", "#0000FF"),   Colors.black);
+    Colors.spect_pkB = disp->alloc_color (xrm->get (".color.spect.pkB", "#8080FF"),   Colors.black);
+    Colors.spect_trX = disp->alloc_color (xrm->get (".color.spect.trM", "darkgreen"), Colors.black);
+    Colors.spect_trY = disp->alloc_color (xrm->get (".color.spect.trM", "magenta"),   Colors.black);
     Colors.butt_bg0  = disp->alloc_color (xrm->get (".color.butt.bg0",  "#e0d8d0"),   Colors.white);
     Colors.butt_bg1  = disp->alloc_color (xrm->get (".color.butt.bg1",  "yellow"),    Colors.white);
-    Colors.butt_bgA  = disp->alloc_color (xrm->get (".color.butt.bgA",  "red"),       Colors.black);
-    Colors.butt_bgB  = disp->alloc_color (xrm->get (".color.butt.bgB",  "blue"),      Colors.black);
-    Colors.butt_bgM  = disp->alloc_color (xrm->get (".color.butt.bgM",  "green"),     Colors.white);
+    Colors.butt_bgA  = Colors.spect_trA;
+    Colors.butt_bgB  = Colors.spect_trB;
+    Colors.butt_bgX  = Colors.spect_trX;
+    Colors.butt_bgY  = Colors.spect_trY;
 
     XftColors.white    = disp->alloc_xftcolor ("white", 0);
     XftColors.black    = disp->alloc_xftcolor ("black", 0);
@@ -60,7 +62,8 @@ void init_styles (X_display *disp, X_resman *xrm)
     XftColors.butt_fg1 = disp->alloc_xftcolor (xrm->get (".color.butt.fg1",  "black"), XftColors.black);
     XftColors.butt_fgA = disp->alloc_xftcolor (xrm->get (".color.butt.fgA",  "white"), XftColors.white);
     XftColors.butt_fgB = disp->alloc_xftcolor (xrm->get (".color.butt.fgB",  "white"), XftColors.white);
-    XftColors.butt_fgM = disp->alloc_xftcolor (xrm->get (".color.butt.fgM",  "black"), XftColors.black);
+    XftColors.butt_fgX = disp->alloc_xftcolor (xrm->get (".color.butt.fgM",  "white"), XftColors.white);
+    XftColors.butt_fgY = disp->alloc_xftcolor (xrm->get (".color.butt.fgM",  "white"), XftColors.white);
  
     XftFonts.about1 = disp->alloc_xftfont (xrm->get (".font.about1", "times:pixelsize=24"));
     XftFonts.about2 = disp->alloc_xftfont (xrm->get (".font.about2", "times:pixelsize=14"));
@@ -88,9 +91,13 @@ void init_styles (X_display *disp, X_resman *xrm)
     BstB.color.bg [1] = Colors.butt_bgB;
     BstB.color.fg [1] = XftColors.butt_fgB;
 
-    BstM = Bst0;
-    BstM.color.bg [1] = Colors.butt_bgM;
-    BstM.color.fg [1] = XftColors.butt_fgM;
+    BstX = Bst0;
+    BstX.color.bg [1] = Colors.butt_bgX;
+    BstX.color.fg [1] = XftColors.butt_fgX;
+
+    BstY = Bst0;
+    BstY.color.bg [1] = Colors.butt_bgY;
+    BstY.color.fg [1] = XftColors.butt_fgY;
 
     Tst0.font = XftFonts.labels;
     Tst0.color.normal.bgnd = Colors.white;
