@@ -38,12 +38,14 @@ struct colors
     unsigned long   spect_pkA;
     unsigned long   spect_trB;
     unsigned long   spect_pkB;
-    unsigned long   spect_trM;
+    unsigned long   spect_trX;
+    unsigned long   spect_trY;
     unsigned long   butt_bg0;
     unsigned long   butt_bg1;
     unsigned long   butt_bgA;
     unsigned long   butt_bgB;
-    unsigned long   butt_bgM;
+    unsigned long   butt_bgX;
+    unsigned long   butt_bgY;
 };
 
 
@@ -64,7 +66,8 @@ struct xft_colors
     XftColor  *butt_fg1;
     XftColor  *butt_fgA;
     XftColor  *butt_fgB;
-    XftColor  *butt_fgM;
+    XftColor  *butt_fgX;
+    XftColor  *butt_fgY;
 };
 
 
@@ -83,7 +86,7 @@ extern struct colors       Colors;
 extern struct fonts        Fonts;
 extern struct xft_colors   XftColors;
 extern struct xft_fonts    XftFonts;
-extern X_button_style      Bst0, BstA, BstB, BstM;
+extern X_button_style      Bst0, BstA, BstB, BstX, BstY;
 extern X_textln_style      Tst0, Tst1;
 
 
